==> inti-media-1.0.3-41a9bc.tar: src/Handler/Upload.php <==
<?php
declare(strict_types=1);

namespace Inti\Media\Handler;

use Inti\Media\Model\ImagePath;
use Inti\Media\Service\ImageManager;
use Laminas\Diactoros\Response\TextResponse;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\RequestHandlerInterface;

use function ltrim;
use function md5;

/**
 * Class Upload
 *
 * @package Inti\Media\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-media
 */
final class Upload implements RequestHandlerInterface
{
    private ImageManager $images;

    /**
     * Konstruktor.
     *
     * @param ImageManager $images
     */
    public function __construct(ImageManager $images)
    {
        $this->images = $images;
    }

    /**
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        $path = ltrim($request->getUri()->getPath(), '/');
        $path = (new ImagePath($path))->sanitize()->setExtension('webp')->getFullPath();

        if ($this->images->has($path)) {
            $responseCode = 200;
        } else {
            $imageData = $request->getBody()->getContents();
            $path = $this->images->write($path, $imageData);
            $responseCode = 201;
        }

        $imageData = $this->images->read($path);
        $md5 = md5($imageData);
        $path = $path . '?' . substr($md5, 0, 8);

        return new TextResponse($path, $responseCode);
    }
}

==> inti-media-1.1.5-643a4c.tar: src/Handler/Upload.php <==
<?php
declare(strict_types=1);

namespace Inti\Media\Handler;

use Inti\Media\Model\ImagePath;
use Inti\Media\Service\ImageManager;
use Laminas\Diactoros\Response\TextResponse;
use Laminas\Filter\FilterInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\RequestHandlerInterface;

use function ltrim;
use function md5;

/**
 * Class Upload
 *
 * @package Inti\Media\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-media
 */
final class Upload implements RequestHandlerInterface
{
    private ImageManager    $images;
    private FilterInterface $pathFilter;

    public function __construct(ImageManager $images, FilterInterface $pathFilter)
    {
        $this->images = $images;
        $this->pathFilter = $pathFilter;
    }

    /**
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        $path = ltrim($request->getUri()->getPath(), '/');
        $path = $this->pathFilter->filter($path);
        $path = (new ImagePath($path))->setExtension('webp')->getFullPath();

        if ($this->images->has($path)) {
            $responseCode = 200;
        } else {
            $imageData = $request->getBody()->getContents();
            $path = $this->images->write($path, $imageData);
            $responseCode = 201;
        }

        $imageData = $this->images->read($path);
        $md5 = md5($imageData);
        $path = $path . '?' . substr($md5, 0, 8);

        return new TextResponse($path, $responseCode);
    }
}
